@@ -3,7 +3,8 @@ import os
 __all__ = ['DEFAULT_PROTOCOL',
            'DESIGNER_ONLINE',
            'STYLESHEET',
-           'STYLESHEET_INCLUDE_DEFAULT'
+           'STYLESHEET_INCLUDE_DEFAULT',
+           'CONFIRM_QUIT'
            ]
 
 
@@ -17,3 +18,5 @@ DESIGNER_ONLINE = os.getenv("PYDM_DESIGNER_ONLINE", None) is not None
 STYLESHEET = os.getenv("PYDM_STYLESHEET", None)
 
 STYLESHEET_INCLUDE_DEFAULT = os.getenv("PYDM_STYLESHEET_INCLUDE_DEFAULT", False)
+
+CONFIRM_QUIT = os.getenv("PYDM_CONFIRM_QUIT", "n").lower() in ("y", "t", "1", "true")
\ No newline at end of file
