@@ -7,7 +7,7 @@ import json
 import numpy as np
 from qtpy.QtWidgets import (QApplication, QMenu, QGraphicsOpacityEffect,
                             QToolTip, QWidget)
-from qtpy.QtGui import QCursor
+from qtpy.QtGui import QCursor, QIcon
 from qtpy.QtCore import Qt, QEvent, Signal, Slot, Property
 from .channel import PyDMChannel
 from .. import data_plugins, tools, config
@@ -28,6 +28,24 @@ except NameError:
     str_types = (str,)
 
 
+def get_icon_file(name):
+    """
+    Returns the full path to the icon represented by name.
+
+    Parameters
+    ----------
+    name : str
+        The filename to load the file path.
+
+    Returns
+    -------
+    str
+    """
+    base_path = os.path.dirname(os.path.realpath(__file__))
+    icon_path = os.path.join(base_path, "icons", "terminator.png")
+    return icon_path
+
+
 def is_channel_valid(channel):
     """
     Verify if a channel string is valid.
@@ -121,6 +139,8 @@ class PyDMPrimitiveWidget(object):
         'Opacity': ['set_opacity', float]
     }
 
+    designer_icon = QIcon()
+
     def __init__(self, **kwargs):
         self.app = QApplication.instance()
         self._rules = None
@@ -215,7 +235,6 @@ class PyDMPrimitiveWidget(object):
         self.setGraphicsEffect(op)
         self.setAutoFillBackground(True)
 
-
     @Slot(dict)
     def rule_evaluated(self, payload):
         """
@@ -241,8 +260,19 @@ class PyDMPrimitiveWidget(object):
             return
 
         method_name, data_type = self.RULE_PROPERTIES[prop]
-        method = getattr(self, method_name)
-        method(value)
+        try:
+            method = getattr(self, method_name)
+            if data_type == bool and isinstance(value, str_types):
+                # We do this as we already import json and for Python:
+                # bool("False") -> True
+                val = json.loads(value.lower())
+            else:
+                val = data_type(value)
+            method(val)
+        except:
+            logger.error('Error at Rule: %s. Could not execute method %s with '
+                         'value %s and type as %s.',
+                         name, method_name, value, data_type.__name__)
 
     @Property(str, designable=False)
     def rules(self):
