@@ -8,7 +8,7 @@ logger = logging.getLogger(__name__)
 from qtpy.QtWidgets import QLineEdit, QMenu, QApplication
 from qtpy.QtCore import Property, Q_ENUMS
 from .. import utilities
-from .base import PyDMWritableWidget, TextFormatter
+from .base import PyDMWritableWidget, TextFormatter, str_types
 from .display_format import DisplayFormat, parse_value_for_display
 
 
@@ -229,7 +229,7 @@ class PyDMLineEdit(QLineEdit, TextFormatter, PyDMWritableWidget, DisplayFormat):
                                          DisplayFormat.Exponential,
                                          DisplayFormat.Hex,
                                          DisplayFormat.Binary]:
-            if not isinstance(new_value, (str, np.ndarray)):
+            if self.channeltype not in (str, np.ndarray):
                 try:
                     new_value *= self.channeltype(self._scale)
                 except TypeError:
@@ -241,7 +241,10 @@ class PyDMLineEdit(QLineEdit, TextFormatter, PyDMWritableWidget, DisplayFormat):
                                             string_encoding=self._string_encoding,
                                             widget=self)
 
-        self._display = str(new_value)
+        if type(new_value) in str_types:
+            self._display = new_value
+        else:
+            self._display = str(new_value)
 
         if self._display_format_type == DisplayFormat.Default:
             if isinstance(new_value, (int, float)):
@@ -250,7 +253,7 @@ class PyDMLineEdit(QLineEdit, TextFormatter, PyDMWritableWidget, DisplayFormat):
                 return
 
         if self._show_units:
-            self._display += " {}".format(self._unit)
+            self._display = "{} {}".format(self._display, self._unit)
 
         self.setText(self._display)
 
